import type { DefaultTheme } from "./theme-provider";
import { Maybe } from "./typeUtils";
type LowercaseCharacter = "a" | "b" | "c" | "d" | "e" | "f" | "g" | "h" | "i" | "j" | "k" | "l" | "m" | "n" | "o" | "p" | "q" | "r" | "s" | "t" | "u" | "v" | "w" | "x" | "y" | "z";
type AllCharacter = LowercaseCharacter | Uppercase<LowercaseCharacter>;
type NonEmptyString = `${AllCharacter}${string}`;
type CSSLengthUnit = `${number}${LengthUnit}`;
type CSSCustomProperties = `--${NonEmptyString}`;
type CSSCustomPropertiesWithVar = `var(${CSSCustomProperties})`;
type LengthUnit = "vmin" | "vmax" | "vh" | "vw" | "%" | "ch" | "ex" | "em" | "rem" | "in" | "cm" | "mm" | "pt" | "pc" | "px";
export type CSSLength = CSSLengthUnit | CSSCustomPropertiesWithVar | CSSCustomProperties;
export declare function checkIsCSSLength(str: string): str is CSSLength;
export declare const spacing: Record<"size000" | "size00" | "size1" | "size2" | "size3" | "size4" | "size5" | "size6" | "size7" | "size8" | "size9" | "size10" | "size11" | "size12" | "size13" | "size14" | "size15", CSSLength>;
export declare const sizes: Record<"sizeXxs" | "sizeXs" | "sizeSm" | "sizeMd" | "sizeLg" | "sizeXl" | "sizeXxl" | "sizeContent1" | "sizeContent2" | "sizeContent3" | "sizeHeader1" | "sizeHeader2" | "sizeHeader3", CSSLength>;
export type BaseTheme = Record<string, CSSLength | string | number>;
type ThemeOrDefaultSpace<T> = T extends {
    space: BaseTheme;
} ? keyof T["space"] : keyof typeof spacing;
export type SpacingOptions = ThemeOrDefaultSpace<DefaultTheme>;
export type SizesOptions = ThemeOrDefaultSizes<DefaultTheme>;
type ThemeOrDefaultSizes<T> = T extends {
    sizes: BaseTheme;
} ? T["sizes"] : keyof typeof sizes;
export type Gutter = CSSLength | number | SpacingOptions;
export declare function getSafeGutter<T extends DefaultTheme>(theme: T, gutter?: Gutter): Maybe<CSSLength>;
export declare function getSpacingValue<T extends DefaultTheme>(theme: Readonly<T & {
    space?: BaseTheme;
}>, spacingKey: SpacingOptions): Maybe<CSSLength>;
export declare function getSizeValue<T extends DefaultTheme>(theme: Readonly<T & {
    sizes?: BaseTheme;
}>, sizeKey?: CSSLength | number | SizesOptions | "fit-content" | "max-content" | "min-content" | "auto"): Maybe<CSSLength>;
export {};
